Home
last modified time | relevance | path

Searched refs:hh (Results 1 – 25 of 63) sorted by relevance

123

/freebsd-12-stable/contrib/libucl/uthash/
Duthash.h95 #define HASH_FIND(hh,head,keyptr,keylen,out) \ argument
100 HASH_FCN(keyptr,keylen, (head)->hh.tbl->num_buckets, _hf_hashv, _hf_bkt); \
101 if (HASH_BLOOM_TEST((head)->hh.tbl, _hf_hashv)) { \
102 HASH_FIND_IN_BKT((head)->hh.tbl, hh, (head)->hh.tbl->buckets[ _hf_bkt ], \
142 #define HASH_MAKE_TABLE(hh,head) \ argument
144 (head)->hh.tbl = (UT_hash_table*)uthash_malloc( \
146 if (!((head)->hh.tbl)) { uthash_fatal( "out of memory"); } \
147 memset((head)->hh.tbl, 0, sizeof(UT_hash_table)); \
148 (head)->hh.tbl->tail = &((head)->hh); \
149 (head)->hh.tbl->num_buckets = HASH_INITIAL_NUM_BUCKETS; \
[all …]
/freebsd-12-stable/contrib/elftoolchain/common/
Duthash.h96 #define HASH_FIND(hh,head,keyptr,keylen,out) \ argument
101 HASH_FCN(keyptr,keylen, (head)->hh.tbl->num_buckets, _hf_hashv, _hf_bkt); \
102 if (HASH_BLOOM_TEST((head)->hh.tbl, _hf_hashv)) { \
103 HASH_FIND_IN_BKT((head)->hh.tbl, hh, (head)->hh.tbl->buckets[ _hf_bkt ], \
142 #define HASH_MAKE_TABLE(hh,head) \ argument
144 (head)->hh.tbl = (UT_hash_table*)uthash_malloc( \
146 if (!((head)->hh.tbl)) { uthash_fatal( "out of memory"); } \
147 memset((head)->hh.tbl, 0, sizeof(UT_hash_table)); \
148 (head)->hh.tbl->tail = &((head)->hh); \
149 (head)->hh.tbl->num_buckets = HASH_INITIAL_NUM_BUCKETS; \
[all …]
/freebsd-12-stable/sys/geom/
Dgeom_subr.c89 struct g_hh00 *hh; in g_load_class() local
100 hh = arg; in g_load_class()
101 mp = hh->mp; in g_load_class()
102 hh->error = 0; in g_load_class()
103 if (hh->post) { in g_load_class()
104 g_free(hh); in g_load_class()
105 hh = NULL; in g_load_class()
114 if (hh != NULL) in g_load_class()
115 hh->error = EEXIST; in g_load_class()
120 if (hh != NULL) in g_load_class()
[all …]
/freebsd-12-stable/sys/ofed/drivers/infiniband/ulp/sdp/
Dsdp_cma.c269 struct sdp_hh hh; in sdp_cma_handler() local
315 memset(&hh, 0, sizeof hh); in sdp_cma_handler()
316 hh.bsdh.mid = SDP_MID_HELLO; in sdp_cma_handler()
317 hh.bsdh.len = htonl(sizeof(struct sdp_hh)); in sdp_cma_handler()
318 hh.max_adverts = 1; in sdp_cma_handler()
319 hh.ipv_cap = 0x40; in sdp_cma_handler()
320 hh.majv_minv = SDP_MAJV_MINV; in sdp_cma_handler()
322 hh.bsdh.bufs = htons(rx_ring_posted(sdp_sk(sk))); in sdp_cma_handler()
323 hh.localrcvsz = hh.desremrcvsz = htonl(sdp_sk(sk)->recv_bytes); in sdp_cma_handler()
324 hh.max_adverts = 0x1; in sdp_cma_handler()
[all …]
Dsdp_bcopy.c44 struct sdp_hh *hh; in _dump_packet() local
59 hh = (struct sdp_hh *)h; in _dump_packet()
63 hh->max_adverts, hh->majv_minv, in _dump_packet()
64 ntohl(hh->localrcvsz), in _dump_packet()
65 ntohl(hh->desremrcvsz)); in _dump_packet()
/freebsd-12-stable/crypto/openssl/crypto/mdc2/
Dmdc2dgst.c35 memset(&(c->hh[0]), 0x25, MDC2_BLOCK); in MDC2_Init()
86 c->hh[0] = (c->hh[0] & 0x9f) | 0x20; in mdc2_body()
92 DES_set_odd_parity(&c->hh); in mdc2_body()
93 DES_set_key_unchecked(&c->hh, &k); in mdc2_body()
104 p = c->hh; in mdc2_body()
124 memcpy(&(md[MDC2_BLOCK]), (char *)c->hh, MDC2_BLOCK); in MDC2_Final()
/freebsd-12-stable/contrib/ntp/scripts/stats/
DREADME.timecodes35 "<CR><LF>i ddd hh:mm:ss TZ=zz<CR><LF>"
41 hh:mm:ss = hours, minutes, seconds
53 "<CR><LF>iqyy ddd hh:mm:ss.fff ld"
62 hh:mm:ss.fff = hours, minutes, seconds, milliseconds of day
78 "<CR><LF><^A>ddd:hh:mm:ssq<CR>"
82 hh:mm:ss = hours, minutes, seconds
95 "<CR>hh:mm:ss.f dd/mm/yy<CR>"
99 hh:mm:ss = hours, minutes, seconds
105 hh:mm:ss.? once synch is established and then lost again for about
123 hh = WWVH propagation delay (81 = 33 ms)
[all …]
/freebsd-12-stable/contrib/tnftp/src/
Dprogressbar.c317 int remaining, hh, i; local
346 hh = remaining / SECSPERHOUR;
348 if (hh)
349 len += snprintf(buf + len, BUFLEFT, "%2d:", hh);
366 hh = remaining / SECSPERHOUR;
369 if (hh)
370 len += snprintf(buf + len, BUFLEFT, "%2d:", hh);
/freebsd-12-stable/contrib/ntp/include/
Dntp_types.h185 int16_t hh; uint16_t hl; uint16_t lh; uint16_t ll; member
188 uint16_t hh; uint16_t hl; uint16_t lh; uint16_t ll; member
198 uint16_t ll; uint16_t lh; uint16_t hl; int16_t hh;
201 uint16_t ll; uint16_t lh; uint16_t hl; uint16_t hh;
/freebsd-12-stable/usr.bin/calendar/
Dcalendar.c171 long utcoffset, hh, mm, ss; in main() local
178 hh = utcoffset / SECSPERHOUR; in main()
187 uo = hh + uo / 100; in main()
Dsunpos.c195 #define DEBUG1(y, m, d, hh, mm, pdec, dec) \ argument
197 y, m, d, hh, mm, pdec, dec)
198 #define DEBUG2(y, m, d, hh, mm, pdec, dec, pang, ang) \ argument
200 y, m, d, hh, mm, pdec, dec, pang, ang)
Dparsedata.c1033 int hh, mm, ss, i; in floattotime() local
1038 hh = i / SECSPERHOUR; in floattotime()
1044 sprintf(buf, "%02d:%02d:%02d", hh, mm, ss); in floattotime()
1052 int i, m, d, hh, mm, ss; in floattoday() local
1062 hh = i / SECSPERHOUR; in floattoday()
1068 sprintf(buf, "%02d-%02d %02d:%02d:%02d", m, d, hh, mm, ss); in floattoday()
/freebsd-12-stable/contrib/tzdata/
Dziguard.awk58 hh, mm, ss, seconds, dot_dddd, subseconds)
63 hh = mm = ss = timestamp
66 sub(/^[-+]?/, "", hh)
67 seconds = 3600 * hh + 60 * mm + ss
/freebsd-12-stable/contrib/ntp/sntp/
Dutilities.c144 int hh, mm, lto, isdst; in tv_to_str() local
163 hh = lto / 60; in tv_to_str()
176 hh, in tv_to_str()
/freebsd-12-stable/contrib/llvm-project/clang/include/clang/Basic/
DBuiltinsAMDGPU.def177 TARGET_BUILTIN(__builtin_amdgcn_rcph, "hh", "nc", "16-bit-insts")
178 TARGET_BUILTIN(__builtin_amdgcn_sqrth, "hh", "nc", "16-bit-insts")
179 TARGET_BUILTIN(__builtin_amdgcn_rsqh, "hh", "nc", "16-bit-insts")
180 TARGET_BUILTIN(__builtin_amdgcn_sinh, "hh", "nc", "16-bit-insts")
181 TARGET_BUILTIN(__builtin_amdgcn_cosh, "hh", "nc", "16-bit-insts")
183 TARGET_BUILTIN(__builtin_amdgcn_frexp_manth, "hh", "nc", "16-bit-insts")
185 TARGET_BUILTIN(__builtin_amdgcn_fracth, "hh", "nc", "16-bit-insts")
DBuiltins.def129 BUILTIN(__builtin_fabsf16, "hh" , "ncF")
206 BUILTIN(__builtin_ceilf16, "hh" , "Fnc")
211 BUILTIN(__builtin_cosf16, "hh" , "Fne")
228 BUILTIN(__builtin_expf16, "hh" , "Fne")
233 BUILTIN(__builtin_exp2f16, "hh" , "Fne")
246 BUILTIN(__builtin_floorf16, "hh" , "Fnc")
287 BUILTIN(__builtin_log10f16, "hh" , "Fne")
296 BUILTIN(__builtin_log2f16, "hh" , "Fne")
304 BUILTIN(__builtin_logf16, "hh" , "Fne")
337 BUILTIN(__builtin_rintf16, "hh", "Fnc")
[all …]
/freebsd-12-stable/sys/contrib/libsodium/src/libsodium/crypto_onetimeauth/poly1305/sse2/
Dpoly1305_sse2.c43 uint32_t hh[10]; member
117 _mm_storeu_si128((xmmi *) (void *) &st->H.hh[0], _mm_setzero_si128()); in poly1305_init_ext()
118 _mm_storeu_si128((xmmi *) (void *) &st->H.hh[4], _mm_setzero_si128()); in poly1305_init_ext()
119 _mm_storeu_si128((xmmi *) (void *) &st->H.hh[8], _mm_setzero_si128()); in poly1305_init_ext()
239 T0 = _mm_loadu_si128((const xmmi *) (const void *) &st->H.hh[0]); in poly1305_blocks()
240 T1 = _mm_loadu_si128((const xmmi *) (const void *) &st->H.hh[4]); in poly1305_blocks()
241 T2 = _mm_loadu_si128((const xmmi *) (const void *) &st->H.hh[8]); in poly1305_blocks()
681 _mm_storeu_si128((xmmi *) (void *) &st->H.hh[0], T0); in poly1305_blocks()
682 _mm_storeu_si128((xmmi *) (void *) &st->H.hh[4], T1); in poly1305_blocks()
683 _mm_storel_epi64((xmmi *) (void *) &st->H.hh[8], T4); in poly1305_blocks()
/freebsd-12-stable/contrib/tcsh/nls/et/
Dset143 1 \nÄhh!! Liiga palju %s!!\n
/freebsd-12-stable/crypto/openssl/include/openssl/
Dmdc2.h28 DES_cblock h, hh; member
/freebsd-12-stable/contrib/llvm-project/libcxx/include/
Dccomplex26 // hh 080623 Created
/freebsd-12-stable/contrib/tcsh/nls/ja/
Dset1112 110 形式: sched -<項目番号>.\n形式: sched [+]hh:mm <コマンド>
/freebsd-12-stable/contrib/bearssl/tools/
Dclient.c217 print_hashes(unsigned hh, unsigned hh2) in print_hashes() argument
225 if (((hh >> i) & 1) != 0) { in print_hashes()
234 choose_hash(unsigned hh) in choose_hash() argument
244 if (((hh >> f[u]) & 1) != 0) { in choose_hash()
/freebsd-12-stable/contrib/tzcode/zic/
Dzic.c895 long hh; local
906 if (sscanf(string, scheck(string, "%ld"), &hh) == 1)
908 else if (sscanf(string, scheck(string, "%ld:%d"), &hh, &mm) == 2)
911 &hh, &mm, &ss) != 3) {
915 if (hh < 0 ||
921 if (LONG_MAX / SECSPERHOUR < hh) {
925 if (noise && hh == HOURSPERDAY && mm == 0 && ss == 0)
927 if (noise && (hh > HOURSPERDAY ||
928 (hh == HOURSPERDAY && (mm != 0 || ss != 0))))
930 return oadd(eitol(sign) * hh * eitol(SECSPERHOUR),
/freebsd-12-stable/contrib/llvm-project/llvm/lib/Target/NVPTX/
DNVPTXRegisterInfo.td39 def HH#i : NVPTXReg<"%hh"#i>; // 2x16-bit float
/freebsd-12-stable/crypto/heimdal/doc/
Ddoxytmpl.dxy96 *.hh \

123